require 'datadog/statsd'
require 'logging'
require_relative 'base'

class DataDogMetricsBackend < MetricsBackend    
    def initialize(host: 'localhost', port: 8125, logger: Logging.logger(STDOUT))        
        @statsd = get_statsd(host, port)
        @logger = logger
    end

    def get_statsd(host, port)
        Datadog::Statsd.new(host, port)
    end

    def increment(metric, tags: [])
        @logger.debug "increment #{metric}"

        @statsd.increment(metric, tags: tags)
    end

    def gauge(metric, value, tags: [])
        @logger.debug "gauge #{metric} to #{value}"

        @statsd.gauge(metric, value, tags: tags) 
    end

    def histogram(metric, value, tags: [])
        @logger.debug "histogram #{metric} to #{value}"

        @statsd.histogram(metric, value, tags: tags)
    end

    def timed(metric, duration, tags: [])
        @logger.debug "time #{metric} as #{duration}"

        @statsd.timing(metric, duration, tags: tags)
    end
end
